@@ -7,7 +7,7 @@
 #     modify it under the same terms as Perl itself.
 
 package SNMP;
-$VERSION = '5.0904';   # current release version number
+$VERSION = '5.05';   # current release version number
 
 use strict;
 use warnings;
@@ -59,7 +59,7 @@ sub AUTOLOAD {
     my $constname;
     ($constname = $AUTOLOAD) =~ s/.*:://;
     # croak "&$module::constant not defined" if $constname eq 'constant';
-    ($!, $val) = constant($constname, @_ ? $_[0] : 0);
+    $val = constant($constname, @_ ? $_[0] : 0);
     if ($! != 0) {
 	if ($! =~ /Invalid/) {
 	    $AutoLoader::AUTOLOAD = $AUTOLOAD;
@@ -135,26 +135,6 @@ $replace_newer = 0; # determine whether or not to tell the parser to replace
                     # older MIB modules with newer ones when loading MIBs.
                     # WARNING: This can cause an incorrect hierarchy.
 
-sub register_debug_tokens {
-    my $tokens = shift;
-
-    SNMP::_register_debug_tokens($tokens);
-}
-
-sub getenv {
-    my $name = shift;
-
-    return SNMP::_getenv($name);
-}
-
-sub setenv {
-    my $envname = shift;
-    my $envval = shift;
-    my $overwrite = shift;
-
-    return SNMP::_setenv($envname, $envval, $overwrite);
-}
-
 sub setMib {
 # loads mib from file name provided
 # setting second arg to true causes currently loaded mib to be replaced
@@ -167,10 +147,10 @@ sub setMib {
 }
 
 sub initMib {
-# equivalent to calling the snmp library init_mib if Mib is NULL
+# eqivalent to calling the snmp library init_mib if Mib is NULL
 # if Mib is already loaded this function does nothing
-# Pass a zero valued argument to get minimal mib tree initialization
-# If non zero argument or no argument then full mib initialization
+# Pass a zero valued argument to get minimal mib tree initialzation
+# If non zero agrgument or no argument then full mib initialization
 
   SNMP::init_snmp("perl");
   return;
@@ -223,10 +203,10 @@ sub translateObj {
 # Translate object identifier(tag or numeric) into alternate representation
 # (i.e., sysDescr => '.1.3.6.1.2.1.1.1' and '.1.3.6.1.2.1.1.1' => sysDescr)
 # when $SNMP::use_long_names or second arg is non-zero the translation will
-# return longer textual identifiers (e.g., system.sysDescr).  An optional
+# return longer textual identifiers (e.g., system.sysDescr).  An optional 
 # third argument of non-zero will cause the module name to be prepended
-# to the text name (e.g. 'SNMPv2-MIB::sysDescr').  If no Mib is loaded
-# when called and $SNMP::auto_init_mib is enabled then the Mib will be
+# to the text name (e.g. 'SNMPv2-MIB::sysDescr').  If no Mib is loaded 
+# when called and $SNMP::auto_init_mib is enabled then the Mib will be 
 # loaded. Will return 'undef' upon failure.
    SNMP::init_snmp("perl");
    my $obj = shift;
@@ -267,8 +247,8 @@ sub mapEnum {
   my $var = shift;
   my ($tag, $val, $update);
   if (ref($var) =~ /ARRAY/ or ref($var) =~ /Varbind/) {
-      $tag = SNMP::Varbind::tag($var);
-      $val = SNMP::Varbind::val($var);
+      $tag = $var->[$SNMP::Varbind::tag_f];
+      $val = $var->[$SNMP::Varbind::val_f];
       $update = 1;
   } else {
       $tag = $var;
@@ -276,7 +256,7 @@ sub mapEnum {
   }
   my $iflag = $val =~ /^\d+$/;
   my $res = SNMP::_map_enum($tag, $val, $iflag, $SNMP::best_guess);
-  if ($update and defined $res) { SNMP::Varbind::val($var) = $res; }
+  if ($update and defined $res) { $var->[$SNMP::Varbind::val_f] = $res; }
   return($res);
 }
 
@@ -350,17 +330,17 @@ sub snmp_trap {
     $sess->trap(@_);
 }
 
-#---------------------------------------------------------------------
-# Preserves the ability to call MainLoop() with no args so we don't
+#--------------------------------------------------------------------- 
+# Preserves the ability to call MainLoop() with no args so we don't 
 # break old code
 #
-# Alternately, MainLoop() could be called as an object method,
-# ( $sess->MainLoop() ) , so that $self winds up in @_.  Then it would
+# Alternately, MainLoop() could be called as an object method, 
+# ( $sess->MainLoop() ) , so that $self winds up in @_.  Then it would 
 # be more like :
 # my $self = shift;
-# ....
+# .... 
 # SNMP::_main_loop(......, $self->{SessPtr});
-#---------------------------------------------------------------------
+#--------------------------------------------------------------------- 
 sub MainLoop {
     my $ss = shift if(&SNMP::_api_mode() == SNMP::SNMP_API_SINGLE());
     my $time = shift;
@@ -427,16 +407,16 @@ sub _tie {
 }
 
 sub split_vars {
-    # This sub holds the regex that is used throughout this module
+    # This sub holds the regex that is used throughout this module  
     #  to parse the base part of an OID from the IID.
-    #  eg: portName.9.30 -> ['portName','9.30']
+    #  eg: portName.9.30 -> ['portName','9.30'] 
     my $vars = shift;
 
     # The regex was changed to this simple form by patch 722075 for some reason.
-    # Testing shows now (2/05) that it is not needed, and that the long expression
+    # Testing shows now (2/05) that it is not needed, and that the long expression 
     # works fine.  AB
     # my ($tag, $iid) = ($vars =~ /^(.*?)\.?(\d+)+$/);
-
+    
     # These following two are the same.  Broken down for easier maintenance
     # my ($tag, $iid) = ($vars =~ /^((?:\.\d+)+|(?:\w+(?:\-*\w+)+))\.?(.*)$/);
     my ($tag, $iid) =
@@ -471,8 +451,8 @@ sub new {
    $this->{ErrorStr} = ''; # if methods return undef check for expln.
    $this->{ErrorNum} = 0;  # contains SNMP error return
 
-   $this->{Version} ||=
-     NetSNMP::default_store::netsnmp_ds_get_int(NetSNMP::default_store::NETSNMP_DS_LIBRARY_ID,
+   $this->{Version} ||= 
+     NetSNMP::default_store::netsnmp_ds_get_int(NetSNMP::default_store::NETSNMP_DS_LIBRARY_ID, 
 				      NetSNMP::default_store::NETSNMP_DS_LIB_SNMPVERSION) ||
 					SNMP::SNMP_DEFAULT_VERSION();
 
@@ -488,7 +468,7 @@ sub new {
    $this->{DestHost} ||= 'localhost';
 
    # community defaults to public
-   $this->{Community} ||= NetSNMP::default_store::netsnmp_ds_get_string(NetSNMP::default_store::NETSNMP_DS_LIBRARY_ID(),
+   $this->{Community} ||= NetSNMP::default_store::netsnmp_ds_get_string(NetSNMP::default_store::NETSNMP_DS_LIBRARY_ID(), 
 				        NetSNMP::default_store::NETSNMP_DS_LIB_COMMUNITY()) || 'public';
 
    # number of retries before giving up, defaults to SNMP_DEFAULT_RETRIES
@@ -504,11 +484,6 @@ sub new {
        $this->{DestHost} = $this->{DestHost} . ":" . $this->{RemotePort};
    }
 
-   if ($this->{DestHost} =~ /^(dtls|tls|ssh)/) {
-       # only works with version 3
-       $this->{Version} = 3;
-   }
-
    if ($this->{Version} eq '1' or $this->{Version} eq '2'
        or $this->{Version} eq '2c') {
        $this->{SessPtr} = SNMP::_new_session($this->{Version},
@@ -519,101 +494,68 @@ sub new {
 					     $this->{Timeout},
 					     );
    } elsif ($this->{Version} eq '3' ) {
-       $this->{SecName} ||=
-	   NetSNMP::default_store::netsnmp_ds_get_string(NetSNMP::default_store::NETSNMP_DS_LIBRARY_ID(),
-		         NetSNMP::default_store::NETSNMP_DS_LIB_SECNAME()) ||
+       $this->{SecName} ||= 
+	   NetSNMP::default_store::netsnmp_ds_get_string(NetSNMP::default_store::NETSNMP_DS_LIBRARY_ID(), 
+		         NetSNMP::default_store::NETSNMP_DS_LIB_SECNAME()) || 
 			   'initial';
        if (!$this->{SecLevel}) {
-	   $this->{SecLevel} =
-	       NetSNMP::default_store::netsnmp_ds_get_int(NetSNMP::default_store::NETSNMP_DS_LIBRARY_ID(),
-			  NetSNMP::default_store::NETSNMP_DS_LIB_SECLEVEL()) ||
+	   $this->{SecLevel} = 
+	       NetSNMP::default_store::netsnmp_ds_get_int(NetSNMP::default_store::NETSNMP_DS_LIBRARY_ID(), 
+			  NetSNMP::default_store::NETSNMP_DS_LIB_SECLEVEL()) || 
 			      $SNMP::V3_SEC_LEVEL_MAP{'noAuthNoPriv'};
        } elsif ($this->{SecLevel} !~ /^\d+$/) {
 	   $this->{SecLevel} = $SNMP::V3_SEC_LEVEL_MAP{$this->{SecLevel}};
        }
        $this->{SecEngineId} ||= '';
        $this->{ContextEngineId} ||= $this->{SecEngineId};
-       $this->{Context} ||=
-	   NetSNMP::default_store::netsnmp_ds_get_string(NetSNMP::default_store::NETSNMP_DS_LIBRARY_ID(),
+       $this->{Context} ||= 
+	   NetSNMP::default_store::netsnmp_ds_get_string(NetSNMP::default_store::NETSNMP_DS_LIBRARY_ID(), 
 		         NetSNMP::default_store::NETSNMP_DS_LIB_CONTEXT()) || '';
+       $this->{AuthProto} ||= 'DEFAULT'; # use the library's default
+       $this->{AuthPass} ||=
+       NetSNMP::default_store::netsnmp_ds_get_string(NetSNMP::default_store::NETSNMP_DS_LIBRARY_ID(), 
+		     NetSNMP::default_store::NETSNMP_DS_LIB_AUTHPASSPHRASE()) ||
+       NetSNMP::default_store::netsnmp_ds_get_string(NetSNMP::default_store::NETSNMP_DS_LIBRARY_ID(), 
+		     NetSNMP::default_store::NETSNMP_DS_LIB_PASSPHRASE()) || '';
 
-       if ($this->{DestHost} =~ /^(dtls|tls|ssh)/) {
-	   # this is a tunneled protocol
+       $this->{AuthMasterKey} ||= '';
+       $this->{PrivMasterKey} ||= '';
+       $this->{AuthLocalizedKey} ||= '';
+       $this->{PrivLocalizedKey} ||= '';
 
-	   $this->{'OurIdentity'} ||= '';
-	   $this->{'TheirIdentity'} ||= '';
-	   $this->{'TheirHostname'} ||= '';
-	   $this->{'TrustCert'} ||= '';
+       $this->{PrivProto} ||= 'DEFAULT';  # use the library's default
+       $this->{PrivPass} ||=
+       NetSNMP::default_store::netsnmp_ds_get_string(NetSNMP::default_store::NETSNMP_DS_LIBRARY_ID(), 
+		     NetSNMP::default_store::NETSNMP_DS_LIB_PRIVPASSPHRASE()) ||
+       NetSNMP::default_store::netsnmp_ds_get_string(NetSNMP::default_store::NETSNMP_DS_LIBRARY_ID(), 
+		     NetSNMP::default_store::NETSNMP_DS_LIB_PASSPHRASE()) || '';
+       $this->{EngineBoots} = 0 if not defined $this->{EngineBoots};
+       $this->{EngineTime} = 0 if not defined $this->{EngineTime};
 
-	   $this->{'SecLevel'} = $SNMP::V3_SEC_LEVEL_MAP{'authPriv'};
-
-	   $this->{SessPtr} =
-	     SNMP::_new_tunneled_session($this->{Version},
-					 $this->{DestHost},
-					 $this->{Retries},
-					 $this->{Timeout},
-					 $this->{SecName},
-					 $this->{SecLevel},
-					 $this->{ContextEngineId},
-					 $this->{Context},
-					 $this->{'OurIdentity'},
-					 $this->{'TheirIdentity'},
-					 $this->{'TheirHostname'},
-					 $this->{'TrustCert'},
-					);
-
-
-       } else {
-	   # USM or some other internal security protocol
-
-	   # USM specific parameters:
-	   $this->{AuthProto} ||= 'DEFAULT'; # use the library's default
-	   $this->{AuthPass} ||=
-	     NetSNMP::default_store::netsnmp_ds_get_string(NetSNMP::default_store::NETSNMP_DS_LIBRARY_ID(),
-							   NetSNMP::default_store::NETSNMP_DS_LIB_AUTHPASSPHRASE()) ||
-							       NetSNMP::default_store::netsnmp_ds_get_string(NetSNMP::default_store::NETSNMP_DS_LIBRARY_ID(),
-													     NetSNMP::default_store::NETSNMP_DS_LIB_PASSPHRASE()) || '';
-
-	   $this->{AuthMasterKey} ||= '';
-	   $this->{PrivMasterKey} ||= '';
-	   $this->{AuthLocalizedKey} ||= '';
-	   $this->{PrivLocalizedKey} ||= '';
-
-	   $this->{PrivProto} ||= 'DEFAULT'; # use the library's default
-	   $this->{PrivPass} ||=
-	     NetSNMP::default_store::netsnmp_ds_get_string(NetSNMP::default_store::NETSNMP_DS_LIBRARY_ID(),
-							   NetSNMP::default_store::NETSNMP_DS_LIB_PRIVPASSPHRASE()) ||
-							       NetSNMP::default_store::netsnmp_ds_get_string(NetSNMP::default_store::NETSNMP_DS_LIBRARY_ID(),
-													     NetSNMP::default_store::NETSNMP_DS_LIB_PASSPHRASE()) || '';
-	   $this->{EngineBoots} = 0 if not defined $this->{EngineBoots};
-	   $this->{EngineTime} = 0 if not defined $this->{EngineTime};
-
-	   $this->{SessPtr} =
-	     SNMP::_new_v3_session($this->{Version},
-				   $this->{DestHost},
-				   $this->{Retries},
-				   $this->{Timeout},
-				   $this->{SecName},
-				   $this->{SecLevel},
-				   $this->{SecEngineId},
-				   $this->{ContextEngineId},
-				   $this->{Context},
-				   $this->{AuthProto},
-				   $this->{AuthPass},
-				   $this->{PrivProto},
-				   $this->{PrivPass},
-				   $this->{EngineBoots},
-				   $this->{EngineTime},
-				   $this->{AuthMasterKey},
-				   length($this->{AuthMasterKey}),
-				   $this->{PrivMasterKey},
-				   length($this->{PrivMasterKey}),
-				   $this->{AuthLocalizedKey},
-				   length($this->{AuthLocalizedKey}),
-				   $this->{PrivLocalizedKey},
-				   length($this->{PrivLocalizedKey}),
-				  );
-       }
+       $this->{SessPtr} = SNMP::_new_v3_session($this->{Version},
+						$this->{DestHost},
+						$this->{Retries},
+						$this->{Timeout},
+						$this->{SecName},
+						$this->{SecLevel},
+						$this->{SecEngineId},
+						$this->{ContextEngineId},
+						$this->{Context},
+						$this->{AuthProto},
+						$this->{AuthPass},
+						$this->{PrivProto},
+						$this->{PrivPass},
+						$this->{EngineBoots},
+						$this->{EngineTime},
+						$this->{AuthMasterKey},
+						length($this->{AuthMasterKey}),
+						$this->{PrivMasterKey},
+						length($this->{PrivMasterKey}),
+						$this->{AuthLocalizedKey},
+						length($this->{AuthLocalizedKey}),
+						$this->{PrivLocalizedKey},
+						length($this->{PrivLocalizedKey}),
+					       );
    }
    unless ($this->{SessPtr}) {
        warn("unable to create session") if $SNMP::verbose;
@@ -622,9 +564,9 @@ sub new {
 
    SNMP::initMib($SNMP::auto_init_mib); # ensures that *some* mib is loaded
 
-   $this->{UseLongNames} = $SNMP::use_long_names
+   $this->{UseLongNames} = $SNMP::use_long_names 
        unless exists $this->{UseLongNames};
-   $this->{UseSprintValue} = $SNMP::use_sprint_value
+   $this->{UseSprintValue} = $SNMP::use_sprint_value 
        unless exists $this->{UseSprintValue};
    $this->{BestGuess} = $SNMP::best_guess unless exists $this->{BestGuess};
    $this->{NonIncreasing} ||= $SNMP::non_increasing;
@@ -651,9 +593,9 @@ sub update {
 
    @$this{keys %new_fields} = values %new_fields;
 
-   $this->{UseLongNames} = $SNMP::use_long_names
+   $this->{UseLongNames} = $SNMP::use_long_names 
        unless exists $this->{UseLongNames};
-   $this->{UseSprintValue} = $SNMP::use_sprint_value
+   $this->{UseSprintValue} = $SNMP::use_sprint_value 
        unless exists $this->{UseSprintValue};
    $this->{BestGuess} = $SNMP::best_guess unless exists $this->{BestGuess};
    $this->{NonIncreasing} ||= $SNMP::non_increasing;
@@ -754,7 +696,7 @@ sub gettable {
     return if (!$root_oid);
 
     # deficed if we're going to parse indexes
-    my $parse_indexes = (defined($state->{'options'}{'noindexes'})) ?
+    my $parse_indexes = (defined($state->{'options'}{'noindexes'})) ? 
       0 : $have_netsnmp_oid;
 
     # get the list of columns we should look at.
@@ -783,7 +725,7 @@ sub gettable {
 		# least one column.  We pick the last.
 		push @{$state->{'columns'}}, $root_oid . ".1." .
 		  $children->[$#$children]{'subID'}
-		  if ref($state) eq 'HASH' and ref($children) eq 'ARRAY';
+		  if ref($state) eq 'HASH' and ref($children) eq 'HASH';
 	    }
 	}
     } else {
@@ -811,7 +753,7 @@ sub gettable {
     }
 
     $vbl = $state->{'varbinds'};
-
+	
     my $repeatcount;
     if ($this->{Version} eq '1' || $state->{'options'}{nogetbulk}) {
 	$state->{'repeatcount'} = 1;
@@ -827,10 +769,6 @@ sub gettable {
 	# varbinds.
 	$state->{'repeatcount'} = int(1000 / 36 / ($#{$state->{'varbinds'}} + 1));
     }
-    # Make sure we run at least once
-    if ($state->{'repeatcount'} < 1) {
-	$state->{'repeatcount'} = 1;
-    }
 
     #
     # if we've been configured with a callback, then call the
@@ -890,7 +828,7 @@ sub _gettable_do_it() {
 	    my $row_value = $vbl->[$i][2];
 	    my $row_type = $vbl->[$i][3];
 
-	    if ($row_oid =~
+	    if ($row_oid =~ 
 		/^$state->{'stopconds'}[$i % ($#{$state->{'stopconds'}}+1)]/ &&
 		$row_value ne 'ENDOFMIBVIEW' ){
 
@@ -1020,10 +958,10 @@ sub fget {
    SNMP::_get($this, $this->{RetryNoSuch}, $varbind_list_ref, $cb);
 
    foreach my $varbind (@$varbind_list_ref) {
-     my $sub = $this->{VarFormats}{SNMP::Varbind::tag($varbind)} ||
-	      $this->{TypeFormats}{SNMP::Varbind::type($varbind)};
+     my $sub = $this->{VarFormats}{$varbind->[$SNMP::Varbind::tag_f]} ||
+	 $this->{TypeFormats}{$varbind->[$SNMP::Varbind::type_f]};
      &$sub($varbind) if defined $sub;
-     push(@res, SNMP::Varbind::val($varbind));
+     push(@res, $varbind->[$SNMP::Varbind::val_f]);
    }
 
    return(wantarray() ? @res : $res[0]);
@@ -1073,10 +1011,10 @@ sub fgetnext {
    SNMP::_getnext($this, $varbind_list_ref, $cb);
 
    foreach my $varbind (@$varbind_list_ref) {
-     my $sub = $this->{VarFormats}{SNMP::Varbind::tag($varbind)} ||
-	      $this->{TypeFormats}{SNMP::Varbind::type($varbind)};
+     my $sub = $this->{VarFormats}{$varbind->[$SNMP::Varbind::tag_f]} ||
+	 $this->{TypeFormats}{$varbind->[$SNMP::Varbind::type_f]};
      &$sub($varbind) if defined $sub;
-     push(@res, SNMP::Varbind::val($varbind));
+     push(@res, $varbind->[$SNMP::Varbind::val_f]);
    }
 
    return(wantarray() ? @res : $res[0]);
@@ -1185,7 +1123,7 @@ sub trap {
      $varbind_list_ref = $vars if ref($$vars[0]) =~ /ARRAY/;
    }
 
-   if ($this->{Version} =~ '^1') {
+   if ($this->{Version} eq '1') {
        my $enterprise = $param{enterprise} || 'ucdavis';
        $enterprise = SNMP::translateObj($enterprise)
 	   unless $enterprise =~ /^[\.\d]+$/;
@@ -1196,12 +1134,10 @@ sub trap {
        my $specific = $param{specific} || 0;
        @res = SNMP::_trapV1($this, $enterprise, $agent, $generic, $specific,
 			  $uptime, $varbind_list_ref);
-   } elsif ($this->{Version} =~ '^[23]') {
+   } elsif  (($this->{Version} eq '2')|| ($this->{Version} eq '2c')) {
        my $trap_oid = $param{oid} || $param{trapoid} || '.0.0';
        my $uptime = $param{uptime} || SNMP::_sys_uptime();
        @res = SNMP::_trapV2($this, $uptime, $trap_oid, $varbind_list_ref);
-   } else {
-     warn("error:trap: Unsupported SNMP version " . $this->{Version} . "\n");
    }
 
    return(wantarray() ? @res : $res[0]);
@@ -1236,7 +1172,7 @@ sub inform {
    my $trap_oid = $param{oid} || $param{trapoid};
    my $uptime = $param{uptime} || SNMP::_sys_uptime();
 
-   if ($this->{Version} =~ '^[23]') {
+   if($this->{Version} eq '3') {
      @res = SNMP::_inform($this, $uptime, $trap_oid, $varbind_list_ref, $cb);
    } else {
      warn("error:inform: This version doesn't support the command\n");
@@ -1261,11 +1197,11 @@ sub new {
 
 package SNMP::Varbind;
 
-$SNMP::Varbind::tag_f = 0;
-$SNMP::Varbind::iid_f = 1;
-$SNMP::Varbind::val_f = 2;
-$SNMP::Varbind::type_f = 3;
-$SNMP::Varbind::time_f = 4;
+my $tag_f = 0;
+my $iid_f = 1;
+my $val_f = 2;
+my $type_f = 3;
+my $time_f = 4;
 
 sub new {
    my $type = shift;
@@ -1275,27 +1211,27 @@ sub new {
 }
 
 sub tag {
-  $_[0]->[$SNMP::Varbind::tag_f];
+  $_[0]->[$tag_f];
 }
 
 sub iid {
-  $_[0]->[$SNMP::Varbind::iid_f];
+  $_[0]->[$iid_f];
 }
 
 sub val {
-  $_[0]->[$SNMP::Varbind::val_f];
+  $_[0]->[$val_f];
 }
 
 sub type {
-  $_[0]->[$SNMP::Varbind::type_f];
+  $_[0]->[$type_f];
 }
 
 sub name {
-   if (defined($_[0]->[$SNMP::Varbind::iid_f]) && ($_[0]->[$SNMP::Varbind::iid_f] =~ m/^[0-9]+$/)) {
-      return $_[0]->[$SNMP::Varbind::tag_f] . "." . $_[0]->[$SNMP::Varbind::iid_f];
+   if (defined($_[0]->[$iid_f]) && ($_[0]->[$iid_f] =~ m/^[0-9]+$/)) {
+      return $_[0]->[$tag_f] . "." . $_[0]->[$iid_f];
    }
 
-   return $_[0]->[$SNMP::Varbind::tag_f];
+   return $_[0]->[$tag_f];
 }
 
 sub fmt {
@@ -1541,7 +1477,7 @@ init_snmp properly, which means it will read configuration files and
 use those defaults where appropriate automatically parse MIB files,
 etc.  This will likely affect your perl applications if you have, for
 instance, default values set up in your snmp.conf file (as the perl
-module will now make use of those defaults).  The documentation,
+module will now make use of those defaults).  The docmuentation,
 however, has sadly not been updated yet (aside from this note), nor is
 the read_config default usage implementation fully complete.
 
@@ -1552,7 +1488,7 @@ aspects of a connection between the management application and the
 managed agent. Internally the class is implemented as a blessed hash
 reference. This class supplies 'get', 'getnext', 'set', 'fget', and
 'fgetnext' method calls. The methods take a variety of input argument
-formats and support both synchronous and asynchronous operation through
+formats and support both syncronous and asyncronous operation through
 a polymorphic API (i.e., method behaviour varies dependent on args
 passed - see below).
 
@@ -1562,150 +1498,77 @@ $sess = new SNMP::Session(DestHost => 'host', ...)
 
 The following arguments may be passed to new as a hash.
 
-=head2 Basic Options
-
 =over 4
 
 =item DestHost
 
-Hostname or IP address of the SNMP agent you want to talk to.
-Specified in Net-SNMP formatted agent addresses.  These addresses
-typically look like one of the following:
+default 'localhost', hostname or ip addr of SNMP agent
 
-  localhost
-  tcp:localhost
-  tls:localhost
-  tls:localhost:9876
-  udp6:[::1]:9876
-  unix:/some/path/to/file/socket
+=item Community
 
-Defaults to 'localhost'.
+default 'public', SNMP community string (used for both R/W)
 
 =item Version
 
-SNMP version to use.
+default taken from library configuration - probably 3 [1, 2 (same as 2c), 2c, 3]
 
-The default is taken from library configuration - probably 3 [1, 2
-(same as 2c), 2c, 3].
+=item RemotePort
+
+default '161', allow remote UDP port to be overriden
 
 =item Timeout
 
-The number of micro-seconds to wait before resending a request.
-
-The default is '1000000'
+default '1000000', micro-seconds before retry
 
 =item Retries
 
-The number of times to retry a request.
-
-The default is '5'
+default '5', retries before failure
 
 =item RetryNoSuch
 
-If enabled NOSUCH errors in 'get' pdus will
+default '0', if enabled NOSUCH errors in 'get' pdus will
 be repaired, removing the varbind in error, and resent -
 undef will be returned for all NOSUCH varbinds, when set
 to '0' this feature is disabled and the entire get request
 will fail on any NOSUCH error (applies to v1 only)
 
-The default is '0'.
-
-=back
-
-=head2 SNMPv3/TLS Options
-
-=over
-
-=item OurIdentity
-
-Our X.509 identity to use, which should either be a fingerprint or the
-filename that holds the certificate.
-
-=item TheirIdentity
-
-The remote server's identity to connect to, specified as either a
-fingerprint or a file name.  Either this must be specified, or the
-hostname below along with a trust anchor.
-
-=item TheirHostname
-
-The remote server's hostname that is expected.  If their certificate
-was signed by a CA then their hostname presented in the certificate
-must match this value or the connection fails to be established (to
-avoid man-in-the-middle attacks).
-
-=item TrustCert
-
-A trusted certificate to use as trust anchor (like a CA certificate)
-for verifying a remote server's certificate.  If a CA certificate is
-used to validate a certificate then the TheirHostname parameter must
-also be specified to ensure their presented hostname in the certificate
-matches.
-
-=back
-
-=head2 SNMPv3/USM Options
-
-=over
-
 =item SecName
 
-The SNMPv3 security name to use (most for SNMPv3 with USM).
-
-The default is 'initial'.
+default 'initial', security name (v3)
 
 =item SecLevel
 
-The SNMPv3 security level to use [noAuthNoPriv, authNoPriv, authPriv] (v3)
-
-The default is 'noAuthNoPriv'.
+default 'noAuthNoPriv', security level [noAuthNoPriv,
+authNoPriv, authPriv] (v3)
 
 =item SecEngineId
 
-The SNMPv3 security engineID to use (if the snmpv3 security model
-needs it; for example USM). The format is as a string without the leading '0x'.
-So if snmptrapd.conf has C<-e 0x8000000001020304>, use C<< SecEngineId =>
-'8000000001020304' >>.
-
-The default is <none>, security engineID and it will be probed if not
+default <none>, security engineID, will be probed if not
 supplied (v3)
 
 =item ContextEngineId
 
-The SNMPv3 context engineID to use.
-
-The default is the <none> and will be set either to the SecEngineId
-value if set or discovered or will be discovered in other ways if
-using TLS (RFC5343 based discovery).
+default <SecEngineId>, context engineID, will be
+probed if not supplied (v3)
 
 =item Context
 
-The SNMPv3 context name to use.
-
-The default is '' (an empty string)
+default '', context name (v3)
 
 =item AuthProto
 
-The SNMPv3/USM authentication protocol to use [MD5, SHA].
-
-The default is 'MD5'.
+default 'MD5', authentication protocol [MD5, SHA] (v3)
 
 =item AuthPass
 
-The SNMPv3/USM authentication passphrase to use.
-
 default <none>, authentication passphrase
 
 =item PrivProto
 
-The SNMPv3/USM privacy protocol to use [DES, AES].
-
-The default is 'DES'.
+default 'DES', privacy protocol [DES, AES] (v3)
 
 =item PrivPass
 
-The SNMPv3/USM privacy passphrase to use.
-
 default <none>, privacy passphrase (v3)
 
 =item AuthMasterKey
@@ -1719,24 +1582,6 @@ default <none>, privacy passphrase (v3)
 Directly specified SNMPv3 USM user keys (used if you want to specify
 the keys instead of deriving them from a password as above).
 
-=back
-
-=head2 SNMPv1 and SNMPv2c Options
-
-=over
-
-=item Community
-
-For SNMPv1 and SNMPv2c, the clear-text community name to use.
-
-The default is 'public'.
-
-=back
-
-=head2 Other Configuration Options
-
-=over
-
 =item VarFormats
 
 default 'undef', used by 'fget[next]', holds an hash
@@ -1792,8 +1637,8 @@ set so that the full OID is returned to the caller.
 
 defaults to the value of SNMP::best_guess at time of session
 creation. this setting controls how <tags> are parsed.  setting to
-0 causes a regular lookup.  setting to 1 causes a regular expression
-match (defined as -Ib in snmpcmd) and setting to 2 causes a random
+0 causes a regular lookup.  setting to 1 causes a regular expression 
+match (defined as -Ib in snmpcmd) and setting to 2 causes a random 
 access lookup (defined as -IR in snmpcmd).
 
 =item NonIncreasing
@@ -1830,11 +1675,6 @@ internal field used to hold the translated DestHost field
 
 internal field used to cache a created session structure
 
-=item RemotePort
-
-Obsolete.  Please use the DestHost specifier to indicate the hostname
-and port combination instead of this paramet.
-
 =back
 
 =head2 SNMP::Session methods
@@ -1853,7 +1693,7 @@ do SNMP GET, multiple <vars> formats accepted.
 for syncronous operation <vars> will be updated
 with value(s) and type(s) and will also return
 retrieved value(s). If <callback> supplied method
-will operate asynchronously
+will operate asyncronously
 
 =item $sess->fget(E<lt>varsE<gt> [,E<lt>callbackE<gt>])
 
@@ -1870,7 +1710,7 @@ and <type>
 
 Note: simple string <vars>,(e.g., 'sysDescr.0')
 form is not updated. If <callback> supplied method
-will operate asynchronously
+will operate asyncronously
 
 =item $sess->fgetnext(E<lt>varsE<gt> [,E<lt>callbackE<gt>])
 
@@ -1886,7 +1726,7 @@ format (i.e., well known format) to ensure unambiguous
 translation to SNMP MIB data value (see discussion of
 canonical value format <vars> description section),
 returns snmp_errno. If <callback> supplied method
-will operate asynchronously
+will operate asyncronously
 
 =item $sess->getbulk(E<lt>non-repeatersE<gt>, E<lt>max-repeatersE<gt>, E<lt>varsE<gt>)
 
@@ -1943,7 +1783,7 @@ agent to include one additional (unrelated) variable that signals
 the end of the sub-tree, allowing bulkwalk() to determine that
 the request is complete.
 
-=item $results = $sess->gettable(E<lt>TABLE OIDE<gt>, E<lt>OPTIONSE<gt>)
+=item $results = $sess->gettable(E<lt>TABLE OIDE<gt>, E<lt>OPTIONS<gt>)
 
 This will retrieve an entire table of data and return a hash reference
 to that data.  The returned hash reference will have indexes of the
@@ -2003,7 +1843,7 @@ collect all the columns defined in the MIB table.
 Specifies a GETBULK repeat I<COUNT>.  IE, it will request this many
 varbinds back per column when using the GETBULK operation.  Shortening
 this will mean smaller packets which may help going through some
-systems.  By default, this value is calculated and attempts to guess
+systems.  By default, this value is calculated and attepmts to guess
 at what will fit all the results into 1000 bytes.  This calculation is
 fairly safe, hopefully, but you can either raise or lower the number
 using this option if desired.  In lossy networks, you want to make
@@ -2015,7 +1855,7 @@ one way to help that.
 Force the use of GETNEXT rather than GETBULK.  (always true for
 SNMPv1, as it doesn't have GETBULK anyway).  Some agents are great
 implementers of GETBULK and this allows you to force the use of
-GETNEXT operations instead.
+GETNEXT oprations instead.
 
 =item callback => \&subroutine
 
@@ -2025,7 +1865,7 @@ If a callback is specified, gettable will return quickly without
 returning results.  When the results are finally retrieved the
 callback subroutine will be called (see the other sections defining
 callback behaviour and how to make use of SNMP::MainLoop which is
-required for this to work).  An additional argument of the normal hash
+required fro this to work).  An additional argument of the normal hash
 result will be added to the callback subroutine arguments.
 
 Note 1: internally, the gettable function uses it's own callbacks
@@ -2041,7 +1881,7 @@ versions prior to 5.04 and 5.04 and up, the following should work:
       $no_mainloop = 1;
   }
 
-Deciding on whether to use SNMP::MainLoop is left as an exercise to
+Deciding on whether to use SNMP::MainLoop is left as an excersize to
 the reader since it depends on whether your code uses other callbacks
 as well.
 
@@ -2255,10 +2095,10 @@ will be undef.
 
 to be used with async SNMP::Session
 calls. MainLoop must be called after initial async calls
-so return packets from the agent will be processed.
-If no args supplied this function enters an infinite loop
+so return packets from the agent will not be processed.
+If no args suplied this function enters an infinite loop
 so program must be exited in a callback or externally
-interrupted. If <timeout(sic)
+interupted. If <timeout(sic)
 
 =item &SNMP::finish()
 
@@ -2325,11 +2165,11 @@ returned.  Set on a per-session basis (see UseNumeric).
 
 =item $SNMP::best_guess
 
-default '0'.  This setting controls how <tags> are
-parsed.  Setting to 0 causes a regular lookup.  Setting
-to 1 causes a regular expression match (defined as -Ib
-in snmpcmd) and setting to 2 causes a random access
-lookup (defined as -IR in snmpcmd).  Can also be set
+default '0'.  This setting controls how <tags> are 
+parsed.  Setting to 0 causes a regular lookup.  Setting 
+to 1 causes a regular expression match (defined as -Ib 
+in snmpcmd) and setting to 2 causes a random access 
+lookup (defined as -IR in snmpcmd).  Can also be set 
 on a per session basis (see BestGuess)
 
 =item $SNMP::save_descriptions
@@ -2340,7 +2180,7 @@ initialization
 
 =item $SNMP::debugging
 
-default '0', controls debugging output level
+default '0', controlls debugging output level
 within SNMP module and libsnmp
 
 =over
@@ -2364,12 +2204,6 @@ level 2 plus snmp_set_dump_packet(1)
 default '0', set [non-]zero to independently set
 snmp_set_dump_packet()
 
-=item SNMP::register_debug_tokens()
-
-Allows to register one or more debug tokens, just like the -D option of snmpd.
-Each debug token enables a group of debug statements. An example:
-SNMP::register_debug_tokens("tdomain,netsnmp_unix");
-
 =back
 
 =head1 %SNMP::MIB
@@ -2483,7 +2317,7 @@ returns true if the last object in the INDEX is IMPLIED
 =item &SNMP::setMib(<file>)
 
 allows dynamic parsing of the mib and explicit
-specification of mib file independent of environment
+specification of mib file independent of enviroment
 variables. called with no args acts like initMib,
 loading MIBs indicated by environment variables (see
 Net-SNMP mib_api docs). passing non-zero second arg
@@ -2530,16 +2364,16 @@ B<*Not Implemented*>
 will convert a text obj tag to an OID and vice-versa.
 Any iid suffix is retained numerically.  Default
 behaviour when converting a numeric OID to text
-form is to return leaf identifier only
-(e.g.,'sysDescr') but when $SNMP::use_long_names
-is non-zero or a non-zero second arg is supplied it
-will return a longer textual identifier.  An optional
-third argument of non-zero will cause the module name
-to be prepended to the text name (e.g.
-'SNMPv2-MIB::sysDescr').  When converting a text obj,
-the $SNMP::best_guess option is used.  If no Mib is
-loaded when called and $SNMP::auto_init_mib is enabled
-then the Mib will be loaded. Will return 'undef' upon
+form is to return leaf identifier only 
+(e.g.,'sysDescr') but when $SNMP::use_long_names 
+is non-zero or a non-zero second arg is supplied it 
+will return a longer textual identifier.  An optional 
+third argument of non-zero will cause the module name 
+to be prepended to the text name (e.g. 
+'SNMPv2-MIB::sysDescr').  When converting a text obj, 
+the $SNMP::best_guess option is used.  If no Mib is 
+loaded when called and $SNMP::auto_init_mib is enabled 
+then the Mib will be loaded. Will return 'undef' upon 
 failure.
 
 =item &SNMP::getType(<var>)
